@@ -140,7 +140,8 @@ class StockDataFrame(DataFrame):
 
         for key in keys:
             if not isinstance(key, str):
-                # It might be an `pandas.DataFrame` indexer type
+                # It might be an `pandas.DataFrame` indexer type,
+                # or an KeyError which we should let pandas raise
                 mapped.append(key)
                 continue
 
@@ -219,7 +220,7 @@ class StockDataFrame(DataFrame):
 
         if size == column_info.size:
             # Already fulfilled
-            return series
+            return series.to_numpy()
 
         delta = size - column_info.size
         offset_slice = slice(- column_info.period - delta + 1, None)
